Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(704)

Unified Diff: chrome/browser/ui/webui/options/profile_settings_reset_browsertest.js

Issue 14924002: WebUI for Profile Settings Reset (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Addressed comments Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/options/profile_settings_reset_browsertest.js
diff --git a/chrome/browser/ui/webui/options/password_manager_browsertest.js b/chrome/browser/ui/webui/options/profile_settings_reset_browsertest.js
similarity index 54%
copy from chrome/browser/ui/webui/options/password_manager_browsertest.js
copy to chrome/browser/ui/webui/options/profile_settings_reset_browsertest.js
index 20d3b67ad042b1f44e5eed967398880db66c8473..6c9392ab732df260f4d3ace77e3ae256f3c6274c 100644
--- a/chrome/browser/ui/webui/options/password_manager_browsertest.js
+++ b/chrome/browser/ui/webui/options/profile_settings_reset_browsertest.js
@@ -3,23 +3,23 @@
// found in the LICENSE file.
/**
* TestFixture for password manager WebUI testing.
* @extends {testing.Test}
* @constructor
**/
-function PasswordManagerWebUITest() {}
+function ProfileSettingsResetWebUITest() {}
-PasswordManagerWebUITest.prototype = {
+ProfileSettingsResetWebUITest.prototype = {
__proto__: testing.Test.prototype,
/**
* Browse to the password manager.
Dan Beam 2013/05/23 19:46:43 ^ fix
battre 2013/05/24 09:15:46 Done.
**/
- browsePreload: 'chrome://settings-frame/passwords',
+ browsePreload: 'chrome://settings-frame/resetProfileSettings',
};
-// Test opening the password manager has correct location.
-TEST_F('PasswordManagerWebUITest', 'testOpenPasswordManager',
+// Test opening the profile settings reset has correct location.
+TEST_F('ProfileSettingsResetWebUITest', 'testOpenProfileSettingsReset',
function() {
assertEquals(this.browsePreload, document.location.href);
});
@@ -3,23 +3,23 @@
// found in the LICENSE file.
/**
- * TestFixture for password manager WebUI testing.
+ * TestFixture for profile settings reset WebUI testing.
* @extends {testing.Test}
* @constructor

Powered by Google App Engine
This is Rietveld 408576698